@@ -31,10 +31,10 @@ class Language(enum.Enum):
     FRENCH = 'fr'
     GREEK = 'el'
     GUJARATI = 'gu'
-    HEBREW = 'he'
+    HEBREW = 'iw'
     HINDI = 'hi'
     SPANISH = 'es'
-    INDONESIAN = 'id'
+    INDONESIAN = 'in'
     JAPANESE = 'ja'
     CANADIAN = 'kn'
     CATALAN = 'ca'
